commit 0ed08d920ab733800e10438b951bab9df98c8378
Author: Andreas Kohlbecker <a.kohlbecker@bgbm.org>
Date:   Tue Sep 29 11:15:30 2015 +0200

    configuring new pom.xml for selenium tests and starting to adapt the headless-maven-tests.sh script

diff --git a/modules/cdm_dataportal/test/java/dataportal-selenium-tests/pom.xml b/modules/cdm_dataportal/test/java/dataportal-selenium-tests/pom.xml
index 6448633e..617d5679 100644
--- a/modules/cdm_dataportal/test/java/dataportal-selenium-tests/pom.xml
+++ b/modules/cdm_dataportal/test/java/dataportal-selenium-tests/pom.xml
@@ -98,13 +98,6 @@
       selenium 2 webdriver, see
       http://seleniumhq.org/docs/03_webdriver.html#with-maven
     -->
-    <!--
-    <dependency>
-      <groupId>org.seleniumhq.selenium</groupId>
-      <artifactId>selenium-parent</artifactId>
-      <version>${selenium-version}</version>
-    </dependency>
-     -->
     <dependency>
       <groupId>org.seleniumhq.selenium</groupId>
       <artifactId>selenium-firefox-driver</artifactId>
diff --git a/pom.xml b/pom.xml
index 5508559d..7dc1fb04 100644
--- a/pom.xml
+++ b/pom.xml
@@ -7,9 +7,15 @@
     <groupId>eu.etaxonomy</groupId>
     <artifactId>cdm_dataportal</artifactId>
     <name>CDM Dataportal</name>
-    <packaging>pom</packaging>
+    <packaging>jar</packaging>
     <version>3.9.0</version>
 
+    <properties>
+        <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
+        <!-- for the latest version see http://docs.seleniumhq.org/download/#client-drivers -->
+        <selenium-version>2.45.0</selenium-version>
+    </properties>
+
     <mailingLists>
         <mailingList>
             <name>EDIT Platform Developers</name>
@@ -76,6 +82,14 @@
 
     <build>
         <plugins>
+            <plugin>
+                <artifactId>maven-compiler-plugin</artifactId>
+                <version>3.2</version>
+                <configuration>
+                    <source>1.7</source>
+                    <target>1.7</target>
+                </configuration>
+            </plugin>
             <plugin>
                 <groupId>org.apache.maven.plugins</groupId>
                 <artifactId>maven-deploy-plugin</artifactId>
@@ -155,4 +169,62 @@
         </extensions>
     </build>
 
+    <dependencies>
+        <dependency>
+            <groupId>junit</groupId>
+            <artifactId>junit</artifactId>
+            <version>4.6</version>
+        </dependency>
+        <dependency>
+            <groupId>log4j</groupId>
+            <artifactId>log4j</artifactId>
+            <version>1.2.16</version>
+        </dependency>
+        <dependency>
+            <groupId>commons-lang</groupId>
+            <artifactId>commons-lang</artifactId>
+            <version>2.2</version>
+        </dependency>
+        <!--
+          selenium 2 webdriver, see
+          http://seleniumhq.org/docs/03_webdriver.html#with-maven
+        -->
+        <dependency>
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-firefox-driver</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+        <dependency>
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-support</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+        <dependency>
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-api</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+        <dependency>
+            <!-- Selenese emulation -->
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-java</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+        <dependency>
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-chrome-driver</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+        <dependency>
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-ie-driver</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+        <dependency>
+            <groupId>org.seleniumhq.selenium</groupId>
+            <artifactId>selenium-htmlunit-driver</artifactId>
+            <version>${selenium-version}</version>
+        </dependency>
+    </dependencies>
+
 </project>
\ No newline at end of file

diff --git a/modules/cdm_dataportal/jenkins-ci/headless-maven-tests.sh b/modules/cdm_dataportal/jenkins-ci/headless-maven-tests.sh
index 3be4e8f4..c4ddebfe 100644
--- a/modules/cdm_dataportal/jenkins-ci/headless-maven-tests.sh
+++ b/modules/cdm_dataportal/jenkins-ci/headless-maven-tests.sh
@@ -1,10 +1,14 @@
 #!/bin/bash -x
 #
 # USAGE:
 #     bash -ex /usr/lib/selenium/headlessSelenium.sh MODULE_ROOT
 # whereas MODULE_ROOT points to the cdm_dataportal folder in the jenkins workspace
 #
-MODULE_ROOT=$1
+if [ -z "$WORKSPACE_ROOT" ]; then
+    WORKSPACE_ROOT=$1
+fi
+
 FIREFOX_BIN="/usr/lib/iceweasel/firefox-bin"
 
 DISPLAY=":99"
@@ -26,7 +30,7 @@ else
 fi
 export DISPLAY
 
-cd $MODULE_ROOT/test/java/dataportal-selenium-tests/
+cd $WORKSPACE_ROOT
 
 if [ -n $2 ]; then
   CONF_FILE_OPTION="-Ddataportal.test.conf=$2"
@@ -1,10 +1,14 @@
 #
 # USAGE:
-#     bash -ex /usr/lib/selenium/headlessSelenium.sh MODULE_ROOT
-# whereas MODULE_ROOT points to the cdm_dataportal folder in the jenkins workspace
+#     bash -ex /usr/lib/selenium/headlessSelenium.sh [WORKSPACE_ROOT]
+# whereas WORKSPACE_ROOT points to workspace root in the jenkins workspace
+# which contains the whole project
 #